==> goodest-1.11.0.tar.gz: goodest-1.11.0/venues/stages/goodest/adventures/vv_turbo/apps/web/src/apps/Earth/logistics/guests/index.js <==


import { createRouter, createWebHistory } from 'vue-router'

import habitat from '@/regions/guests/habitat/decor.vue'

// var intro_path = "/@/"
var intro_path = "/front/@/"
var intro_path_s1 = "/@@/"

export const guests_routes = [
	{
		name: 'habitat',
		path: '/',
		component: habitat
	},
	{
		name: 'herbs',
		path: intro_path + 'herbs',
		component: () => import ('@/regions/guests/vegan_groceries/decor.vue')
	},
	{
		name: 'controls',
		path: intro_path + 'controls',
		component: () => import ('@/parcels/controls/decor.vue')
	},

	{
		name: 'food',
		path: intro_path + 'food/:emblem',
		component: () => import ('@/regions/guests/food/decor.vue')
	},
	{
		name: 'supp',
		path: intro_path + 'supp/:emblem',
		component: () => import ('@/regions/guests/supp/decor.vue')
	},	
	{
		name: 'meal',
		path: intro_path + 'meal/:emblem',
		component: () => import ('@/regions/guests/meal/decor.vue')
	},	
	
	//--
	//
	//	customs
	//
	{
		name: 'goal',
		path: intro_path + 'goal',
		component: () => import ('@/regions/guests/goal/room.vue'),
		children: []
	},
	{
		name: 'presents',
		path: intro_path + 'presents',
		component: () => import ('@/regions/guests/cart/decor.vue'),
		children: []
	},
	{
		name: 'account',
		path: intro_path + 'account',
		component: () => import ('@/regions/guests/account/decor.vue'),
		children: []
	},
	
	//--
	
	{
		name: 'meals',
		path: intro_path + 'meals',
		component: () => import ('@/regions/guests/meals/decor.vue')
	},	
	{
		name: 'map',
		path: intro_path + 'map',
		component: () => import ('@/regions/guests/map/decor.vue')
	},
	
	//--
	
	{
		name: 'navigation lab',
		path: intro_path_s1 + 'navigation-lab',
		component: () => import ('@/parcels/navigation-lab/field.vue')
	},
	{
		name: 'comparisons',
		path: intro_path_s1 + 'comparisons',
		component: () => import ('@/regions/guests/comparisons/region.vue')
	},
	
	//--
	
	{
		name: 'emblem',
		path: intro_path_s1 + 'emblem',
		component: () => import ('@/regions/guests/emblem/decor.vue')
	},	
]

==> goodest-2.1.0.tar.gz: goodest-2.1.0/venues/stages/goodest/adventures/vv_turbo/apps/web/src/apps/Earth/logistics/guests/index.js <==


import { createRouter, createWebHistory } from 'vue-router'

import journal from '@/regions/guests/journal/decor.vue'

// var intro_path = "/@/"
var intro_path = "/front/@/"
var intro_path_s1 = "/@@/"

export const guests_routes = [
	{
		name: 'Journal',
		path: '/',
		component: journal
	},
	{
		name: 'Inventory',
		path: intro_path + 'herbs',
		component: () => import ('@/regions/guests/inventory/decor.vue')
	},
	{
		name: 'Qualities',
		path: intro_path + 'qualities',
		component: () => import ('@/parcels/qualities/decor.vue')
	},

	{
		name: 'food',
		path: intro_path + 'food/:emblem',
		component: () => import ('@/regions/guests/food/decor.vue')
	},
	{
		name: 'supp',
		path: intro_path + 'supp/:emblem',
		component: () => import ('@/regions/guests/supp/decor.vue')
	},	
	{
		name: 'meal',
		path: intro_path + 'meal/:emblem',
		component: () => import ('@/regions/guests/meal/decor.vue')
	},	
	
	//--
	//
	//	customs
	//
	{
		name: 'Goals',
		path: intro_path + 'goals',
		component: () => import ('@/regions/guests/goals/room.vue'),
		children: []
	},
	{
		name: 'Presents',
		path: intro_path + 'presents',
		component: () => import ('@/regions/guests/cart/decor.vue'),
		children: []
	},
	{
		name: 'account',
		path: intro_path + 'account',
		component: () => import ('@/regions/guests/account/decor.vue'),
		children: []
	},
	
	//--
	
	{
		name: 'meals',
		path: intro_path + 'meals',
		component: () => import ('@/regions/guests/meals/decor.vue')
	},	
	{
		name: 'map',
		path: intro_path + 'map',
		component: () => import ('@/regions/guests/map/decor.vue')
	},
	
	//--
	
	{
		name: 'navigation lab',
		path: intro_path_s1 + 'navigation-lab',
		component: () => import ('@/parcels/navigation-lab/field.vue')
	},
	{
		name: 'comparisons',
		path: intro_path_s1 + 'comparisons',
		component: () => import ('@/regions/guests/comparisons/region.vue')
	},
	
	//--
	
	{
		name: 'emblem',
		path: intro_path_s1 + 'emblem',
		component: () => import ('@/regions/guests/emblem/decor.vue')
	},	
]
